==> links_v0.7.0b.zip: links/form.php <==
<?php
/////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//                         Form for Links Ver0.7
//                    Copyright (C) 2002-2003  WHITEWING,Team-act
//             <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This program is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//////////////////////////////////////////////////////////////////////////////

include_once("./config/config.php");
include_once("./system/system.class.php");

//Admin mode
if(_Mode){
header("Location: ./index.php");
exit;
}

//Visitor mode
else{


 //Regist
 switch ($_POST["action"]){
  case 1 :
  //Exception handling
  exception();
  //Write-in processing
  list($no,$url,$burl,$title,$comment,$time,$pass)=nw();
  $msgstr  = $no."\t"
           . $title."\t"
           . $url."\t"
           . $burl."\t"
           . $comment."\t"
           . $pass."\t"
           . "0"."\t"
           . $time."\t"
           . "0\t0\n";

  $msgstr2=$no."\t". $_POST["catg"] . "\t" . $title . "\t" . $no . "\n";
  $path="./data/".$_POST["catg"].".cgi";

  if(!is_writable(_Def_New) || !is_writable($path) || !is_writable(_Def_Site)){
   exit("Permission denied!!");
  }

  regist(_Def_New,$msgstr,TRUE);
  regist($path,$msgstr);
  regist(_Def_Site,$msgstr2);

  if(_Mail){ mail_to_admin($title,$url,$burl); }
  header("Location: ./index.php");
  exit;
  break;


 //Edit form
 case 2 :
  $cat = new find_ctgy($_POST["no"]);
  if(!$cat->find){
  echo ("Scuh No not exist");
  exit;
  }

  //include
  include_once("./system/tmpl2.class.php");
  include_once("./config/languages/japanese.php");
 
  //template
  $tmpl = new Tmpl2("./template/form_edit.tpl.html","EUC-JP","EUC-JP");
  $tmpl->dbgmode(0);

  _Proxy ? $tmp = _Exp11 . _Exp1_1 . _Exp2 : $tmp2 = _Exp11 . _Exp1_2 . _Exp2 ;
  switch (_Tag){
   case 1 : $tmp2 .= _Exp2_1 ;
    break;
   case 2 : $tmp2 .= _Exp2_2 ;
    break;
   case 0 :
   default: $tmp2 .= _Exp2_3 ;
    break;
  }
  _Br ? $tmp2 .= _Exp3 . _Exp3_1 : $tmp2 .= _Exp3 . Exp3_2 ;
  _Auto_link ? $tmp2 .= _Exp4 . _Exp4_1 : $tmp2 .= _Exp4 . _Exp4_2 ;
  $tmp2 .= _Exp6 . stripslashes(_Exp7);

  //File open
  if(!$fp=@fopen("./data/".$cat->find.".cgi","r")){
   echo ("Faild to open file.");
   exit;
  }
  while($dat=fgetcsv($fp,16384,"\t")){
   if($dat[0]==$_POST["no"]){break;}
  }
  $tmpl->assign("NO",$dat[0]);
  $tmpl->assign("TITLE",$dat[1]);
  $tmpl->assign("URL_DAT",$dat[2]);
  $tmpl->assign("BURL",$dat[3]);
  $dat[4]=str_replace("<br />","\n",$dat[4]);
  $tmpl->assign("COMMENT",$dat[4]);
  $tmpl->assign("PASS",$dat[5]);
  if($dat[6]){$tmpl->assign("mv",1);}
  else{$tmpl->assign("mv",0);}
  $tmp = (int)$dat[7];
  $time= new ut2jt($tmp);
  $tmpl->assign("TIME",$time->jt);
  if( time() - date("Z") - $tmp <= _NEW ){$tmpl->assign_def("New");}

 $fp=@fopen(_Def_Ctgy,"r");
 if($fp){
  flock($fp,LOCK_SH);
  $tmpl->loopset("catg");
  while ($ctg_dat=fgetcsv($fp,16384,"\t")){
   $tmpl->assign("ctg_unix",$ctg_dat[0]);
   $tmpl->assign("ctg_name",$ctg_dat[1]);
   if($cat->find == $ctg_dat[0]){
    $tmpl->assign("SELECT",1);
   }
   else{
    $tmpl->assign("NON_SELECT",1);
   }
   $tmpl->loopnext("catg");
   $i++;
  }
  $tmpl->loopend("catg");
  flock($fp,LOCK_UN);
  fclose($fp);
 }
 
  $tmpl->assign("links_title",_Links_Title);
  $tmpl->assign("HomePage",_HomePage);
  $tmpl->assign("admin_mail",_Admin_mail);
  $tmpl->assign("Exp",$tmp2);
  $tmpl->assign("Back2",_Back2);
  $tmpl->assign("Old_Pass",_Old_Pass);
  $tmpl->assign("Title",_Title);
  $tmpl->assign("URL",_URL);
  $tmpl->assign("TIME",$tmp);
  $tmpl->assign("Banner_URL",_Banner_URL);
  $tmpl->assign("Category",_Category);
  $tmpl->assign("Comment",_Comment);
  $tmpl->assign("Password",_Password);
  $tmpl->assign("Clear",_Clear);
  $tmpl->assign("Edit",_Edit);
  $tmpl->assign("Version",_Version);

  if($dat[5]!=md5($_POST["pass"])){
  echo("Password Failed");
  exit;
  }

  header("Cache-Control: no-cash, must-revalidate");
  header("Pragma: no-cash");
  $tmpl->flush();
  exit;
  break;


 case 3 :
  if(_Proxy && $_SERVER["HTTP_VIA"]){
  echo("You don't permit to write!! Why? Now Proxy block mode!");
  exit;
  }
  if(_Ref_Check &&$_SERVER["HTTP_REFERER"]!="http://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]){
  echo("Unjust writing!!");
  exit;
  }
  if(!$_POST["title"] or !$_POST["url"] or $_POST["url"]=="http://" or !$_POST["catg"] or !$_POST["comment"] or !$_POST["old_pass"]){
  exit("Please fill all in.(Exception 'Banner URL')");
  }
  
  $cat= new find_ctgy(&$_POST["no"]);
  $filepath_d="./data/".$cat->find.".cgi";
  $filepath_w="./data/".$_POST["catg"].".cgi";
  if(!file_exists($filepath_w)){exit("Such Category not exist!!");}

  //Password Check
  if(!is_readable($filepath_d)){
   exit("Failed to open (' ".$filepath_d." ')");
  }
  pass_check($filepath_d,$_POST["old_pass"]);

  //write-in process
  list($no,$url,$burl,$title,$comment,$time,$pass)=nw();
  if($_POST["pass"]){$pass=md5($_POST["pass"]);}
  else{$pass=$_POST["pass_md5"];}
  $no=$_POST["no"];
  $time=$_POST["time"];

  $msgstr  = $no."\t"
           . $title."\t"
           . $url."\t"
           . $burl."\t"
           . $comment."\t"
           . $pass."\t"
           . $_POST["mutual"]."\t"
           . $time."\t"
           . "0\t0\n";

  $msgstr2  =$no."\t" .$_POST["catg"]."\t" .$title . "\t" . $no ."\n";


  //Rewrite--Start
  if(!is_writable(_Def_New) || !is_writable($filepath_d) || !is_writable($filepath_w) || !is_writable(_Def_Site)){
   exit("Permission denied!!");
  }
  
  delete_no($filepath_d);

  rewrite($filepath_w,$msgstr,TRUE);
  rewrite(_Def_New,$msgstr);
  rewrite(_Def_Site,$msgstr2);

  header("Location: ./index.php");
  exit;
 break;

 case 4 :
  $cat = new find_ctgy($_POST["no"]);
  if(!$cat->find){exit("Scuh No not exist");}
  //include
  include_once("./system/tmpl2.class.php");
  include_once("./config/languages/japanese.php");
  //template
  $tmpl = new Tmpl2("./template/form_del.tpl.html","EUC-JP","EUC-JP");
  $tmpl->dbgmode(0);
  //File open
  if(!$fp=@fopen("./data/".$cat->find.".cgi","r")){
   echo ("Faild to open file.");
   exit;
  }
  flock($fp,LOCK_SH);
  while($dat=fgetcsv($fp,16384,"\t")){
   if($dat[0]==$_POST["no"]){break;}
  }
  flock($fp,LOCK_UN);
  fclose($fp);
  //Password Check
  if($dat[5]!=md5($_POST["pass"])){exit("Password Failed");}
  //Define
  $tmpl->assign("NO",$dat[0]);
  $tmpl->assign("TITLE",$dat[1]);
  $tmpl->assign("URL",$dat[2]);
  $tmpl->assign("BURL",$dat[3]);
  $tmpl->assign("COMMENT",$dat[4]);
  if($dat[6]){
   $tmpl->assign_def("SOUGO");
  }
  $tmp = (int)$dat[7];
  $time= new ut2jt($tmp);
  $tmpl->assign("TIME",$time->jt);
  if( time() - date("Z") - $tmp <= _NEW ){$tmpl->assign_def("New");}
  $tmpl->assign("No",$_POST["no"]);
  $tmpl->assign("Del_Title",_Del_Title);
  $tmpl->assign("HomePage",_HomePage);
  $tmpl->assign("admin_mail",_Admin_mail);
  $tmpl->assign("Del1",_Del1);
  $tmpl->assign("Back2",_Back2);
  $tmpl->assign("Submit",_Submit);
  $tmpl->assign("Clear",_Clear);
  $tmpl->assign("Version",_Version);
  header("Cache-Control: no-cash, must-revalidate");
  header("Pragma: no-cash");
  $tmpl->flush();
  exit;
 break;

 case 5 :
  //Error exception handling
  if(_Proxy && $_SERVER["HTTP_VIA"]){
   echo("You don't permit to write!! Why? Now Proxy block mode!");
  exit;
  }
  if(_Ref_Check &&$_SERVER["HTTP_REFERER"]!="http://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]){
   echo("Unjust writing!!");
  exit;
  }
  //Search Category by NO
  $cat= new find_ctgy(&$_POST["no"]);
  if(!$cat->find){exit("Such NO does not exist!!");}
  $filepath="./data/".$cat->find.".cgi";
  //Password Check
  if(!is_readable($filepath)){
   exit("Failed to open (' ". $filepath ." ')");
  }
  pass_check($filepath,$_POST["pass"]);
  //Delete process
  if(!is_writable(_Def_New) || !is_writable($filepath) || !is_writable(_Def_Site)){
   exit("Permission denied!!");
  }
  delete_no($filepath);
  delete_no(_Def_New);
  delete_no(_Def_Site);
  header("Location: ./index.php");
  exit;
 break;

 default:
 //include
 include_once("./system/tmpl2.class.php");
 include_once("./config/languages/japanese.php");

 //template
 $tmpl = new Tmpl2("./template/form.tpl.html","EUC-JP","EUC-JP");
 $tmpl->dbgmode(0); 

 //define
 _Proxy ? $tmp = _Exp1 . _Exp1_1 . _Exp2 : $tmp = _Exp1 . _Exp1_2 . _Exp2 ;
 switch (_Tag){
  case 1 : $tmp .= _Exp2_1 ;
   break;
  case 2 : $tmp .= _Exp2_2 ;
   break;
  case 0 :
  default: $tmp .= _Exp2_3 ;
   break;
 }
 _Br ? $tmp .= _Exp3 . _Exp3_1 : $tmp .= _Exp3 . Exp3_2 ;
 _Auto_link ? $tmp .= _Exp4 . _Exp4_1 : $tmp .= _Exp4 . _Exp4_2 ;
 $tmp .= stripslashes(_Exp7);

 $i=0;
 if($fp=@fopen(_Def_Ctgy,"r")){
  flock($fp,LOCK_SH);
  $tmpl->loopset("catg");
  while ($ctg_dat=fgetcsv($fp,16384,"\t")){
   $tmpl->assign("ctg_unix",$ctg_dat[0]);
   $tmpl->assign("ctg_name",$ctg_dat[1]);
   $tmpl->loopnext("catg");
   $i++;
  }
  $tmpl->loopend("catg");
  flock($fp,LOCK_UN);
  fclose($fp);
 }
 else{
  echo("Failed to open file('". _Def_Ctgy ."')");
  exit;
 }

 if(!$fp=fopen(_Def_Site,"r")){
  echo("Failed to open file('". _Def_Site ."')");
  exit;
 }
 flock($fp,LOCK_SH);
 $tmpl->loopset("nodis");
 while ($ctg_dat=fgetcsv($fp,16384,"\t")){
  $tmpl->assign("reg_no",$ctg_dat[0]);
  $tmpl->loopnext("nodis");
 }
 $tmpl->loopend("nodis");
 flock($fp,LOCK_UN);
 fclose($fp);

 $tmpl->assign("links_title",_Links_Title);
 $tmpl->assign("HomePage",_HomePage);
 $tmpl->assign("admin_mail",_Admin_mail);
 $tmpl->assign("form",_Form2);
 $tmpl->assign("Exp",$tmp);
 $tmpl->assign("Regist",_Regist);
 $tmpl->assign("Back2",_Back2);
 $tmpl->assign("Title",_Title);
 $tmpl->assign("URL",_URL);
 $tmpl->assign("Banner_URL",_Banner_URL);
 $tmpl->assign("Category",_Category);
 $tmpl->assign("Comment",_Comment);
 $tmpl->assign("Password",_Password);
 $tmpl->assign("Clear",_Clear);
 $tmpl->assign("EDIT_DELETE",_Edit_Delete);
 $tmpl->assign("Exp5",_Exp5);
 $tmpl->assign("Submit",_Submit);
 $tmpl->assign("Delete",_Delete);
 $tmpl->assign("Edit",_Edit);
 $tmpl->assign("Version",_Version);


 //flush
 $tmpl->flush();
 break;
 }
}
exit;
?>

==> links_v0.7.3a.zip: links/form.php <==
<?php
/////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//                         Form for Links Ver0.7
//                    Copyright (C) 2002-2003  WHITEWING,Team-act
//             <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This program is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//////////////////////////////////////////////////////////////////////////////

include_once("./config/config.php");
include_once("./system/system.class.php");

//Admin mode
if(_Mode){
header("Location: ./index.php");
exit;
}

//Visitor mode
else{
 //Regist
 switch ($_POST["action"]){
  case 1 :
  //Exception handling
  exception();
  //Write-in processing
  $w = new nw_c();
  $msgstr=implode("\t",array($w->no,$w->title,$w->url,$w->burl,$w->comment,$w->pass,"0",$w->time,"0","0","\n"));
  $msgstr2=implode("\t",array($w->no,$_POST["catg"],$w->title,$w->sw,"\n"));
  $path="./data/".$_POST["catg"].".cgi";

  if(!is_writable(_Def_New) || !is_writable($path) || !is_writable(_Def_Site)) exit("Permission denied!!");

  regist(_Def_New,$msgstr,TRUE);
  regist($path,$msgstr);
  regist(_Def_Site,$msgstr2);

  if(_Mail){ mail2admin($title,$url,$burl); }
  header("Location: ./index.php");
  exit;
  break;

 //Edit form
 case 2 :
  $cat = new find_ctgy($_POST["no"]);
  if(!$cat->find){ exit ("Scuh No not exist"); }
  //include
  include_once("./system/tmpl2.class.php");
  include_once("./config/languages/japanese.php");
  //template
  $tmpl = &template("./template/form_edit.tpl.html");
  //Messege
  _Proxy ? $tmp2 = _Exp11 . _Exp1_1 . _Exp2 : $tmp2 = _Exp11 . _Exp1_2 . _Exp2 ;
  switch (_Tag){
   case 1 : $tmp2 .= _Exp2_1 ;
    break;
   case 2 : $tmp2 .= _Exp2_2 ;
    break;
   case 0 :
   default: $tmp2 .= _Exp2_3 ;
    break;
  }
  _Br ? $tmp2 .= _Exp3 . _Exp3_1 : $tmp2 .= _Exp3 . Exp3_2 ;
  _Auto_link ? $tmp2 .= _Exp4 . _Exp4_1 : $tmp2 .= _Exp4 . _Exp4_2 ;
  $tmp2 .= _Exp6;
  //File open
  if(!$fp=@fopen("./data/".$cat->find.".cgi","r")){
   echo ("Faild to open file.");
   exit;
  }
  while($dat=fgetcsv($fp,16384,"\t")){
   if($dat[0]==$_POST["no"]){break;}
  }
  $tmpl->assign("NO",$dat[0]);
  $tmpl->assign("TITLE",$dat[1]);
  $tmpl->assign("URL_DAT",$dat[2]);
  $tmpl->assign("BURL",$dat[3]);
  $tmpl->assign("COMMENT",str_replace("<br />","\n",$dat[4]));
  $tmpl->assign("PASS",$dat[5]);
  if($dat[6]){$tmpl->assign("mv",1);}
  else{$tmpl->assign("mv",0);}
  $tmp = (int)$dat[7];
  $time= new ut2jt($tmp);
  $tmpl->assign("TIME",$time->jt);
  if( time() - date("Z") - $tmp <= _NEW ){$tmpl->assign_def("New");}

 if($fp=@fopen(_Def_Ctgy,"r")){
  flock($fp,LOCK_SH);
  $tmpl->loopset("catg");
  while ($ctg_dat=fgetcsv($fp,16384,"\t")){
   $tmpl->assign("ctg_unix",$ctg_dat[0]);
   $tmpl->assign("ctg_name",$ctg_dat[1]);
   if($cat->find == $ctg_dat[0]){
    $tmpl->assign("SELECT",1);
   }
   else{$tmpl->assign("NON_SELECT",1);}
   $tmpl->loopnext("catg");
   $i++;
  }
  $tmpl->loopend("catg");
  flock($fp,LOCK_UN);
  fclose($fp);
 }
  $tmpl->assign("links_title",_Links_Title);
  $tmpl->assign("HomePage",_HomePage);
  $tmpl->assign("admin_mail",_Admin_mail);
  $tmpl->assign("Exp",$tmp2);
  $tmpl->assign("Back2",_Back2);
  $tmpl->assign("Old_Pass",_Old_Pass);
  $tmpl->assign("Title",_Title);
  $tmpl->assign("DSW",$cat->SW);
  $tmpl->assign("SW",_SW);
  $tmpl->assign("URL",_URL);
  $tmpl->assign("TIME",$tmp);
  $tmpl->assign("Banner_URL",_Banner_URL);
  $tmpl->assign("Category",_Category);
  $tmpl->assign("Comment",_Comment);
  $tmpl->assign("Password",_Password);
  $tmpl->assign("Clear",_Clear);
  $tmpl->assign("Edit",_Edit);
  $tmpl->assign("Version",_Version);

  if($dat[5]!=md5($_POST["pass"])){
  echo("Password Failed");
  exit;
  }

  header("Cache-Control: no-cash, must-revalidate");
  header("Pragma: no-cash");
  $tmpl->flush();
  exit;
  break;


 case 3 :
  if(_Proxy) if($_SERVER["HTTP_VIA"]){
  echo("You don't permit to write!! Why? Now Proxy block mode!");
  exit;
  }
  if(_Ref_Check) if($_SERVER["HTTP_REFERER"]!="http://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]){
  echo("Unjust writing!!");
  exit;
  }
  if(!$_POST["title"] or !$_POST["url"] or $_POST["url"]=="http://" or !$_POST["catg"] or !$_POST["comment"] or !$_POST["old_pass"]){
  exit("Please fill all in.(Exception 'Banner URL')");
  }
  $cat= new find_ctgy(&$_POST["no"]);
  $filepath_d="./data/".$cat->find.".cgi";
  $filepath_w="./data/".$_POST["catg"].".cgi";
  if(!file_exists($filepath_w)){exit("Such Category not exist!!");}
  //Password Check
  if(!is_readable($filepath_d)){ exit("Failed to open (' ".$filepath_d." ')"); }
  pass_check($filepath_d,$_POST["old_pass"]);
  //write-in process
  $w=new nw_c();
  if($_POST["pass"]){$pass=md5($_POST["pass"]);}
  else{$pass=$_POST["pass_md5"];}
  $no=$_POST["no"];
  $time=$_POST["time"];
  $msgstr=implode("\t",array($w->no,$w->title,$w->url,$burl,$w->comment,$w->pass,$_POST["mutual"],$w->time,"0","0","\n"));
  $msgstr2=implode("\t",array($w->no,$_POST["catg"],$w->title,$w->sw,"\n"));
  //Rewrite--Start
  if(!is_writable(_Def_New) || !is_writable($filepath_d) || !is_writable($filepath_w) || !is_writable(_Def_Site)){
   exit("Permission denied!!");
  }
  delete_no($filepath_d);
  rewrite($filepath_w,$msgstr,TRUE);
  rewrite(_Def_New,$msgstr);
  rewrite(_Def_Site,$msgstr2);
  //Jump
  header("Location: ./index.php");
  exit;
  break;

 case 4 :
  $cat = new find_ctgy($_POST["no"]);
  if(!$cat->find){exit("Scuh No not exist");}
  //include
  include_once("./system/tmpl2.class.php");
  include_once("./config/languages/japanese.php");
  //template
  $tmpl=template("./template/form_del.tpl.html");
  //File open
  if(!$fp=@fopen("./data/".$cat->find.".cgi","r")){
   echo ("Faild to open file.");
   exit;
  }
  flock($fp,LOCK_SH);
  while($dat=fgetcsv($fp,16384,"\t")){
   if($dat[0]==$_POST["no"]){break;}
  }
  flock($fp,LOCK_UN);
  fclose($fp);
  //Password Check
  if($dat[5]!=md5($_POST["pass"])){exit("Password Failed");}
  //Define
  $tmpl->assign("NO",$dat[0]);
  $tmpl->assign("TITLE",$dat[1]);
  $tmpl->assign("URL",$dat[2]);
  $tmpl->assign("BURL",$dat[3]);
  $tmpl->assign("COMMENT",$dat[4]);
  if($dat[6]){ $tmpl->assign_def("SOUGO"); }
  $time= new ut2jt((int)$dat[7]);
  $tmpl->assign("TIME",$time->jt);
  if( time() - date("Z") - $tmp <= _NEW ){$tmpl->assign_def("New");}
  $tmpl->assign("No",$_POST["no"]);
  $tmpl->assign("Del_Title",_Del_Title);
  $tmpl->assign("HomePage",_HomePage);
  $tmpl->assign("admin_mail",_Admin_mail);
  $tmpl->assign("Del1",_Del1);
  $tmpl->assign("Back2",_Back2);
  $tmpl->assign("Submit",_Submit);
  $tmpl->assign("Clear",_Clear);
  $tmpl->assign("Version",_Version);
  header("Cache-Control: no-cash, must-revalidate");
  header("Pragma: no-cash");
  $tmpl->flush();
  exit;
 break;

 case 5 :
  //Error exception handling
  if(_Proxy && $_SERVER["HTTP_VIA"]){
   echo("You don't permit to write!! Why? Now Proxy block mode!");
  exit;
  }
  if(_Ref_Check &&$_SERVER["HTTP_REFERER"]!="http://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]){
   echo("Unjust writing!!");
  exit;
  }
  //Search Category by NO
  $cat= new find_ctgy(&$_POST["no"]);
  if(!$cat->find){exit("Such NO does not exist!!");}
  $filepath="./data/".$cat->find.".cgi";
  //Password Check
  if(!is_readable($filepath)){
   exit("Failed to open (' ". $filepath ." ')");
  }
  pass_check($filepath,$_POST["pass"]);
  //Delete process
  if(!is_writable(_Def_New) || !is_writable($filepath) || !is_writable(_Def_Site)){
   exit("Permission denied!!");
  }
  delete_no($filepath);
  delete_no(_Def_New);
  delete_no(_Def_Site);
  header("Location: ./index.php");
  exit;
 break;

 default:
 //include
 include_once("./system/tmpl2.class.php");
 include_once("./config/languages/japanese.php");
 //template
  $tmpl=&template("./template/form.tpl.html");
 //define
 _Proxy ? $tmp = _Exp1 . _Exp1_1 . _Exp2 : $tmp = _Exp1 . _Exp1_2 . _Exp2 ;
 switch (_Tag){
  case 1 : $tmp .= _Exp2_1 ;
   break;
  case 2 : $tmp .= _Exp2_2 ;
   break;
  case 0 :
  default: $tmp .= _Exp2_3 ;
   break;
 }
 _Br ? $tmp .= _Exp3 . _Exp3_1 : $tmp .= _Exp3 . Exp3_2 ;
 _Auto_link ? $tmp .= _Exp4 . _Exp4_1 : $tmp .= _Exp4 . _Exp4_2 ;

 $i=0;
 if(!$fp=@fopen(_Def_Ctgy,"r")){
  exit("Failed to open file('". _Def_Ctgy ."')");
 }
 flock($fp,LOCK_SH);
 $tmpl->loopset("catg");
 while ($ctg_dat=fgetcsv($fp,16384,"\t")){
  $tmpl->assign("ctg_unix",$ctg_dat[0]);
  $tmpl->assign("ctg_name",$ctg_dat[1]);
  $tmpl->loopnext("catg");
  $i++;
 }
 $tmpl->loopend("catg");
 flock($fp,LOCK_UN);
 fclose($fp);

 if(!$fp=fopen(_Def_Site,"r")){
  echo("Failed to open file('". _Def_Site ."')");
  exit;
 }
 flock($fp,LOCK_SH);
 $tmpl->loopset("nodis");
 while ($ctg_dat=fgetcsv($fp,16384,"\t")){
  $tmpl->assign("reg_no",$ctg_dat[0]);
  $tmpl->loopnext("nodis");
 }
 $tmpl->loopend("nodis");
 flock($fp,LOCK_UN);
 fclose($fp);

 $tmpl->assign("links_title",_Links_Title);
 $tmpl->assign("HomePage",_HomePage);
 $tmpl->assign("admin_mail",_Admin_mail);
 $tmpl->assign("form",_Form2);
 $tmpl->assign("Exp",$tmp);
 $tmpl->assign("Regist",_Regist);
 $tmpl->assign("Back2",_Back2);
 $tmpl->assign("Title",_Title);
 $tmpl->assign("URL",_URL);
 $tmpl->assign("Banner_URL",_Banner_URL);
 $tmpl->assign("Category",_Category);
 $tmpl->assign("Comment",_Comment);
 $tmpl->assign("Password",_Password);
 $tmpl->assign("SW",_SW);
 $tmpl->assign("Clear",_Clear);
 $tmpl->assign("EDIT_DELETE",_Edit_Delete);
 $tmpl->assign("Exp5",_Exp5);
 $tmpl->assign("Submit",_Submit);
 $tmpl->assign("Delete",_Delete);
 $tmpl->assign("Edit",_Edit);
 $tmpl->assign("Version",_Version);
 //flush
 $tmpl->flush();
 break;
 }
}
exit;
?>
